Cryptographic Module Validation Program | CSRC
Author: Computer Security Division, Information Technology Laboratory, National Institute of Standards and Technology, U.S. Department of Commerce
Description: Use this form to search for information on validated cryptographic modules. Select the basic search type to search modules on the active validation list. Select the advanced search type to to search modules on the historical and revoked module lists.
Date: 2016-10-11

You are viewing this page in an unauthorized frame window.

This is a potential security issue, you are being redirected to https://csrc.nist.gov.

An official website of the United States government

Official websites use .gov
A .gov website belongs to an official government organization in the United States.

Secure .gov websites use HTTPS
A lock () or https:// means you've safely connected to the .gov website. Share sensitive information only on official, secure websites.

# Cryptographic Module Validation Program CMVP

Share to Facebook Share to Twitter

### Search

Use this form to search for information on validated cryptographic modules.

Select the basic search type to search modules on the active validation list. Select the advanced search type to to search modules on the historical and revoked module lists.

Search Type:
Basic Advanced
Show All
Certificate Number:
Vendor:
Module Name:
Standard:
Module Type:
Validation Status:
Embodiment:
Year Validated:
Level:
Algorithm:
Allowed Algorithms:
Tested Configuration:
Caveat:
Hardware Versions:
Software Versions:
Firmware Versions:
Lab:
Please fix the following:

869 certificates match the search criteria

Certificate Number | Vendor Name | Module Name | Module Type | Validation Date | Status
--- | --- | --- | --- | --- | ---
3651 | Microsoft Corporation | Secure Kernel Code Integrity | Software | 05/07/2020 10/05/2022 | Active
3093 | Microsoft Corporation | Code Integrity | Software | 03/22/2018 06/17/2019 | Active
3090 | Microsoft Corporation | Windows OS Loader | Software | 03/22/2018 06/17/2019 | Active
3850 | DocuSign, Inc. | DocuSign Signature Appliance | Hardware | 03/18/2021 09/15/2021 | Active
3518 | DocuSign, Inc. | DocuSign Signature Appliance | Hardware | 09/05/2019 | Active

Created October 11, 2016, Updated October 26, 2022